@@ -11,7 +11,7 @@ Python Interface to Cologne Digital Sanskrit Lexicon (CDSL).
 
 __author__ = "Hrishikesh Terdalkar"
 __email__ = 'hrishikeshrt@linuxmail.org'
-__version__ = '0.7.0'
+__version__ = '0.9.0'
 
 ###############################################################################
 
@@ -22,5 +22,7 @@ from .constants import (                     # noqa
     SERVER_URL,
     DEFAULT_SCHEME, INTERNAL_SCHEME,
     DEFAULT_CORPUS_DIR,
-    DEFAULT_DICTIONARIES, ENGLISH_DICTIONARIES
+    DEFAULT_DICTIONARIES, ENGLISH_DICTIONARIES,
+    SEARCH_MODE_KEY, SEARCH_MODE_VALUE, SEARCH_MODE_BOTH,
+    DEFAULT_SEARCH_MODE, SEARCH_MODES
 )
