@@ -10,7 +10,12 @@ import argparse
 
 from .corpus import CDSLCorpus
 from .shell import CDSLShell
-from .constants import DEFAULT_SCHEME
+from .constants import (
+    DEFAULT_SCHEME,
+    DEFAULT_SEARCH_MODE,
+    DEFAULT_HISTORY_FILE,
+    DEFAULT_STARTUP_SCRIPT
+)
 from . import __version__
 
 ###############################################################################
@@ -33,54 +38,72 @@ def main():
         "-i",
         "--interactive",
         action="store_true",
-        help="Start in an interactive REPL mode"
+        help="start in an interactive REPL mode"
     )
     parser.add_argument(
         "-s",
         "--search",
-        help="Search pattern. Ignored if `--interactive` mode is set."
+        help="search pattern (ignored if `--interactive` mode is set)"
     )
     parser.add_argument(
         "-p",
         "--path",
-        help="Path to installation"
+        help="path to installation"
     )
     parser.add_argument(
         "-d",
         "--dicts",
         nargs="+",
-        help="Dictionary IDs"
+        help="dictionary id(s)"
+    )
+    parser.add_argument(
+        "-sm",
+        "--search-mode",
+        default=DEFAULT_SEARCH_MODE,
+        help="search mode"
     )
     parser.add_argument(
         "-is",
         "--input-scheme",
         default=DEFAULT_SCHEME,
-        help="Input transliteration scheme"
+        help="input transliteration scheme"
     )
     parser.add_argument(
         "-os",
         "--output-scheme",
         default=DEFAULT_SCHEME,
-        help="Output transliteration scheme"
+        help="output transliteration scheme"
+    )
+    parser.add_argument(
+        "-hf",
+        "--history-file",
+        default=DEFAULT_HISTORY_FILE,
+        help="path to the history file"
+    )
+    parser.add_argument(
+        "-sc",
+        "--startup-script",
+        default=DEFAULT_STARTUP_SCRIPT,
+        help="path to the startup script"
     )
     parser.add_argument(
         "-u",
         "--update",
         action="store_true",
-        help="Update the specified dictionaries."
+        help="update specified dictionaries"
     )
     parser.add_argument(
         "-dbg",
         "--debug",
         action="store_true",
-        help="Turn debug mode on."
+        help="turn debug mode on"
     )
     parser.add_argument(
         "-v",
         "--version",
         action="version",
         version=f"%(prog)s {__version__}",
-        help="Show version and exit."
+        help="show version and exit"
     )
 
     args = vars(parser.parse_args())
@@ -88,9 +111,13 @@ def main():
     # arguments
     data_dir = args.get("path")
     dict_ids = args.get("dicts")
+    search_mode = args.get("search_mode")
     input_scheme = args.get("input_scheme")
     output_scheme = args.get("output_scheme")
 
+    history_file = args.get("history_file")
+    startup_script = args.get("startup_script")
+
     flag_update = args.get("update")
     flag_debug = args.get("debug")
     flag_interactive = args.get("interactive")
@@ -106,15 +133,19 @@ def main():
         cdsl_shell = CDSLShell(
             data_dir=data_dir,
             dict_ids=dict_ids,
+            search_mode=search_mode,
             input_scheme=input_scheme,
-            output_scheme=output_scheme
+            output_scheme=output_scheme,
+            history_file=history_file,
+            startup_script=startup_script
         )
         cdsl_shell.cdsl.setup(dict_ids=dict_ids, update=flag_update)
-        cdsl_shell.cmdloop()
+        return cdsl_shell.cmdloop()
     else:
         # non-interactive shell command
         cdsl = CDSLCorpus(
             data_dir=data_dir,
+            search_mode=search_mode,
             input_scheme=input_scheme,
             output_scheme=output_scheme
         )
