@@ -20,6 +20,15 @@ DEFAULT_SCHEME = sanscript.DEVANAGARI
 
 ###############################################################################
 
+SEARCH_MODE_KEY = "key"
+SEARCH_MODE_VALUE = "value"
+SEARCH_MODE_BOTH = "both"
+
+SEARCH_MODES = [SEARCH_MODE_KEY, SEARCH_MODE_VALUE, SEARCH_MODE_BOTH]
+DEFAULT_SEARCH_MODE = SEARCH_MODE_KEY
+
+###############################################################################
+
 DEFAULT_DICTIONARIES = [
     # Sanskrit-English
     # ----------------
@@ -46,4 +55,7 @@ ENGLISH_DICTIONARIES = ["MWE", "BOR", "AE"]
 HOME_DIR = Path.home()
 DEFAULT_CORPUS_DIR = HOME_DIR / "cdsl_data"
 
+DEFAULT_HISTORY_FILE = HOME_DIR / ".cdsl_history"
+DEFAULT_STARTUP_SCRIPT = HOME_DIR / ".cdslrc"
+
 ###############################################################################
